=====================
TwinDB Infrastructure
=====================

.. image:: https://img.shields.io/pypi/v/twindb_infrastructure.svg
    :target: https://pypi.python.org/pypi/twindb-infrastructure

.. image:: https://readthedocs.org/projects/twindb_infrastructure/badge/?version=master
    :target: http://twindb-infrastructure.readthedocs.io/
    :alt: Documentation Status

.. image:: https://img.shields.io/travis/twindb/twindb_infrastructure.svg
    :target: https://travis-ci.org/twindb/twindb_infrastructure

.. image:: https://img.shields.io/codecov/c/github/twindb/twindb_infrastructure.svg
    :target: https://codecov.io/gh/twindb/twindb_infrastructure


TwinDB Infrastructure is a collection of everything to manage TwinDB infrastructure



Features
--------

* ``twindb-aws`` to manage Amazon EC2 instances
* ``twindb-chef`` to provision a host with Chef
* ``twindb-galera`` to bootstrap a Percona XtraDB cluster

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
